@@ -110,7 +110,10 @@ class Domoticz(IPlugin):
 						log.msg("*********  jsonreq - Temp   :  %s" % (rt['Temp']))
 						log.msg("*********  jsonreq - Name   :  %s" % (rt['Name']))
 						log.msg("*********  jsonreq - Data   :  %s" % (rt['Data']))
-							
+						if local == "temperature" :
+							bodies = "la temperature a été trouvée"
+						if local == "batterie" :
+							bodies = "le niveau de batterie a été trouvé"
 		if bodies == "":
 			bodies = "j'ai rien compris aux devices"
 		return {"plugin": "Domoticz",
